import logging
import sys
class systemInfo():
    def __init__(self):
        self.logger = logging.getLogger("orchestra.system_errors")

    def _check_python_deprecations(self):
        # type: () -> None
        version = sys.version_info[:2]

        if version == (3, 4) or version == (3, 5):
            self.logger.warning(
                "orchestra-sdk 0.0.1 will drop support for Python %s.",
                "{}.{}\nPlease upgrade to the latest version to continue receiving upgrades and bugfixes".format(*version),
            )



from orchestra_logger import orcProcess

def run_example_process(correlation_id, creds):
    orcProcessInstance = orcProcess(correlation_id, creds)
    print('Starting complicated process')
    try:
        print('Trying something complicated')
        raise Exception
    except Exception as e:
        print('Failed to do something complicated')
        orcProcessInstance.sendFailure(message = str(e), data={'some':'arbitrary stuff'})
    finally:
        print('Completed')
        orcProcessInstance.sendCompletion(message = 'Completed')

creds = {'apikey':'my_api_key'}
run_example_process('hello', creds)



from orchestra_logger.services.http.http import simpleHTTP
import uuid

class orcHTTP(simpleHTTP):
    def __init__(self, creds):
        baseUrl = 'http://localhost:8000'
        super().__init__(baseUrl)
        self.add_default_headers({"Authorization": f"Basic {creds['apikey']}"})
        self.add_parameters({"clientid": f"{creds['clientid']}"})
        self.clientid = creds['clientid']

    def send_message(self, correlation_id, data):
        data['correlation_id'] = correlation_id
        data["logid"] = str(uuid.uuid4())
        response = self.base_request(method='POST', endpoint=f"jobs/sdk/sdk_receive", data = json.dumps(data), headers ={
            'Content-Type': 'application/json'})
        return response





import requests

class simpleHTTP:
    def __init__(self, base_url):
        self.base_url = base_url
        self.headers = None
        self.parameters = None

    def add_default_headers(self, headers):
        self.headers = headers
        return self

    def add_headers(self, new_headers):
        if self.headers:
            self.headers = {
                **self.headers,
                **new_headers
            }
            return
        self.headers = new_headers

    def add_parameters(self, new_params):
        if self.parameters:
            self.parameters = {
                **self.parameters,
                **new_params
            }
            return
        self.parameters = new_params

    def base_request(self, endpoint, method="POST", params=None, headers=None, body=None, data=None):
        full_url = self.base_url
        if endpoint:
            full_url = f"{full_url}/{endpoint}"
        if headers:
            self.add_headers(headers)
        if params:
            self.add_parameters(params)
        try:
            response = requests.request(method, full_url, params=self.parameters, headers=self.headers, json=body,
                                        data=data)
            print(response.text)
            return {**response.json(), **{'status_code': response.status_code, 'reason': response.reason}}

        except Exception as error:
            return {
                'status_code': 400,
                'error': str(error)
            }




import inspect
from orchestra_logger.services.orchttp.orchttp import orcHTTP
from datetime import datetime

class orcProcess():
    def __init__(self, correlation_id:str, credentials:dict):
        self.correlation_id = correlation_id
        self.creds = credentials
        if 'apikey' not in self.creds:
            raise ValueError('The credentials object must be a dict that contains an apikey')
        self.client = orcHTTP(self.creds)
        self.kickoff()

    def kickoff(self):
        message = f'Orc process with correlation id {self.correlation_id} started'
        status = 'Running'
        data = {"custom_data":{}}
        try:
            stage = str(inspect.stack()[2][3])
        except:
            stage = 'First function'
        return self.sendMessage(message=message, status=status, stage=stage, data=data)

    def sendMessage(self, message: str, status: str, stage: str, data: dict):

        data = {**data, **{'message':message, 'status':status, 'stage': stage, 'timeUTC':datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")}}
        response = self.client.send_message(self.correlation_id, data)
        return response

    def sendFailure(self, message:str = '', stage:str = 'Process', custom_data:dict = {}):
        """Use this function to send a failure event for an entire process or a given stage"""
        status = 'Failed'
        stage = stage
        function_name__ = str(inspect.stack()[1][3])
        data = {'custom_data': custom_data}
        data['function'] = function_name__
        return self.sendMessage(message=message, status=status, stage=stage, data=data)

    def sendCompletion(self, message:str = '', stage:str = 'Process', custom_data:dict = {}):
        """Use this function to send a completion event for an entire process or a given stage"""
        status = 'Complete'
        stage = stage
        function_name__ = str(inspect.stack()[1][3])
        data = {'custom_data': custom_data}
        data['function'] = function_name__
        return self.sendMessage(message=message, status=status, stage=stage, data=data)

    def sendStageComplete(self, message:str = '', stage:str = 'Process', custom_data:dict = {}):
        """Use this function to send a failure event for an entire process"""
        status = 'Stage passed'
        function_name__ = str(inspect.stack()[1][3])
        data = {'custom_data': custom_data}
        data['function'] = function_name__
        return self.sendMessage(message=message, status=status, stage=stage, data=data)
